@@ -1,10 +1,12 @@
-#! /usr/local/bin/perl -ws
+use v5.10;
+use warnings;
+
 
 use Parse::RecDescent;
 
 sub evalop
 {
-	my (@list) = @{[@{$_[0]}]};
+	my (@list) = @{$_[0]};
 	my $val = shift(@list)->();
 	while (@list)
 	{
